<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/
class Fields_Form_Element_Website extends Engine_Form_Element_Text
{
  public function init()
  {
    //$this->addFilter('PregReplace', array('/\s*[a-zA-Z0-9]{2,5}:\/\//', ''));
    //$this->addValidator('Hostname', true);
  }
}
