<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/
class Fields_View_Helper_FieldZipCode extends Fields_View_Helper_FieldAbstract
{
  public function fieldZipCode($subject, $field, $value)
  {
    return $this->encloseInLink($subject, $field, $value->value, $value->value, true);
  }
}
