<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/
class Fields_View_Helper_FieldFlickr extends Fields_View_Helper_FieldAbstract
{
  public function fieldFlickr($subject, $field, $value)
  {
   $regex = '/^((http(s|):\/\/|)(www\.|)|)flickr\.com\/people\//i';
    
    $username = preg_replace($regex, '', trim($value->value));
    $flickUrl = 'https://www.flickr.com/people/' .  $username;
    
    return $this->view->htmlLink($flickUrl, $value->value, array(
      'target' => '_blank',
      'ref' => 'nofollow',
    ));
    
  }
}
