<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/
class Fields_Form_Element_Country extends Engine_Form_Element_Select
{
  public function init()
  {
    $locale = Zend_Registry::get('Zend_Translate')->getLocale();
		$territories = Zend_Locale::getTranslationList('territory', $locale, 2);
    asort($territories);
    //if( !$this->isRequired() ) {
      $territories = array_merge(array(
        '' => '',
      ), $territories);
    //}
    $this->setMultiOptions($territories);
  }
}
