<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/
class Fields_View_Helper_FieldTextarea extends Fields_View_Helper_FieldAbstract
{
    public function fieldTextarea($subject, $field, $value)
    {
        return nl2br($this->view->string()->htmlspecialchars($value->value));
    }
}
