<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/
class Fields_View_Helper_FieldDate extends Fields_View_Helper_FieldAbstract
{
  public function fieldDate($subject, $field, $value)
  {
    if ( empty($value->value) ) {
        return '';
    }

    $label = $this->view->locale()->toDate($value->value, array(
      'size' => 'long',
      'timezone' => false,
    ));
    //$str = $this->view->date($value->value);
    
    return $this->encloseInLink($subject, $field, $value->value, $label);
  }
}
