<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/
class Fields_Model_Value extends Fields_Model_Abstract
{
  public function getValue()
  {
    return $this->value;
  }

  public function formatValue()
  {
    return $this->value; //.' (formatted)';
  }
}
