<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/
?>
<div style="margin:20px 10px 0 10px;" >
  <form method="post" class="global_form" enctype="application/x-www-form-urlencoded">
    <p class="form-description">
      <?php echo $this->translate("Do you also want to update the Member Level of existing users of your website based on this mapping ?");?>
    </p>
    <div class="form-elements">
      <div id="buttons-wrapper" class="form-wrapper">
        <fieldset id="fieldset-buttons">
          <button type="submit" id="submit" name="submit"><?php echo $this->translate("Yes");?></button>
          <?php echo $this->translate("or");?>
          <a onclick="window.parent.location.reload();" href="javascript:void(0);" type="button" id="cancel" name="cancel">
              <?php echo $this->translate("No");?>
          </a>
        </fieldset>
      </div>
      <input type="hidden" id="userids" value="<?php echo !empty($this->users) ? $this->users : '' ;?>" name="userids">
      <input type="hidden" id="profile_type_id" value="<?php echo $this->profile_type_id;?>" name="profile_type_id">
      <input type="hidden" id="level_id" value="<?php echo $this->level_id;?>" name="level_id">
    </div>
  </form>
</div>
