<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/
abstract class Fields_Model_Abstract extends Engine_Db_Table_Row
{
  public function getFieldType()
  {
    return $this->getTable()->getFieldType();
  }
}
