<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/
class Fields_View_Helper_FieldLocation extends Fields_View_Helper_FieldAbstract
{
  public function fieldLocation($subject, $field, $value)
  {
    return $value->value
      . ' ['
      . $this->view->htmlLink('https://maps.google.com/?q=' . urlencode($value->value), $this->view->translate('map'), array('target' => '_blank'))
      . ']';
  }
}
