<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/
class Fields_Form_Admin_Heading extends Fields_Form_Admin_Field
{
  public function init()
  {
    parent::init();

    $this->setTitle('Add Heading');
    $this->removeElement('description');
    $this->removeElement('error');
    $this->removeElement('required');
    $this->removeElement('icon');
    $this->getElement('label')->setLabel('Heading Label');
    $this->getElement('execute')->setLabel('Save Heading');

    $type = Zend_Controller_Front::getInstance()->getRequest()->getParam('type');
    if( !isset($type) ) {
      $this->removeElement('heading');
      $this->addElement('Hidden', 'type', array(
        'value' => 'heading',
        'order' => 999
      ));
    }
  }
}
