<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/
class Fields_View_Helper_FieldWhatsapp extends Fields_View_Helper_FieldAbstract
{
  public function fieldWhatsapp($subject, $field, $value)
  {
    $whatsappUrl = 'https://wa.me/' .  trim($value->value);

    return $this->view->htmlLink($whatsappUrl, $value->value, array(
      'target' => '_blank',
      'ref' => 'nofollow',
    ));
  }
}
