<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/
class Fields_Model_Option extends Fields_Model_Abstract
{
  public function getFields()
  {
    return Engine_Api::_()->fields()
      ->getFieldsMeta($this->_type)
      ->getRowsMatching('parent_option_id', $this->option_id);
  }
}
