<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/
class Fields_Form_Admin_Field_Birthdate extends Fields_Form_Admin_Field
{
  public function init()
  {
    parent::init();

    // Add minimum age
    $this->addElement('Integer', 'min_age', array(
      'label' => 'Minimum Age',
    ));

    $this->addElement('Select', 'birthday_format', array(
      'label' => 'Default Birthday Format',
       'multiOptions' => array(
            'monthday' => 'Month/Day',
            'monthdayyear' => 'Month/Day/Year',
        ),
       'value'=>'monthdayyear',
    ));
  }
}
